<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="29"/>
        <source>About</source>
        <translation>정보</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>이미지 파일 경로를 인수로 지정하여 응용 프로그램을 시작하여 파일을 불러옵니다.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>이미지 파일을 창으로 끌어다 놓기도 지원됩니다.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="34"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>이 응용 프로그램의 어떤 작업도 디스크의 사진을 변경하지 않습니다.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="35"/>
        <source>Context menu option explanation:</source>
        <translation>상황에 맞는 메뉴 옵션 설명:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>창이 다른 모든 창 위에 오도록 합니다.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="45"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>실수로 창을 닫지 마십시오. (예: 창을 두 번 클릭하여)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="48"/>
        <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
        <translation>이미지 간 전환 시 이미지 보기에 적용되었던 줌/회전/플립 상태를 재설정하지 마세요.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="55"/>
        <source>Version: %1</source>
        <translation>버전: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="66"/>
        <source>Logo designed by %1</source>
        <translation>%1에 의해 설계된 로고</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>Qt %1(%2)로 빌드됨</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="69"/>
        <source>Source code</source>
        <translation>소스 코드</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>Contributors</source>
        <translation>기여자</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>List of contributors on GitHub</source>
        <translation>GitHub의 기여자 목록</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>이 프로젝트에 기여해주신 모든 분들께 감사드립니다.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>Translators</source>
        <translation>번역자</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>이 응용 프로그램 번역에 자원해 주신 다음 분들께 감사의 말씀을 전합니다.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="131"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation>%1은 다음과 같은 무료 소프트웨어 라이브러리를 기반으로 합니다:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="155"/>
        <source>&amp;Special Thanks</source>
        <translation>특별한 감사(&amp;S)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="157"/>
        <source>&amp;Third-party Libraries</source>
        <translation>타사 라이브러리(&amp;T)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Your Rights</source>
        <translation>사용자 권한</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation>저작권 (c) %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="95"/>
        <source>%1 is released under the MIT License.</source>
        <translation>사용자의 권한 %1은 MIT 라이선스에 따라 릴리스됩니다.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="96"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>이 라이선스는 다음과 같은 다양한 자유를 제공합니다:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="97"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>%1을(를) 어떤 용도로도 자유롭게 사용할 수 있습니다</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="98"/>
        <source>You are free to distribute %1</source>
        <translation>%1를 무료로 배포할 수 있습니다</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="99"/>
        <source>You can study how %1 works and change it</source>
        <translation>%1가 작동하는 방식을 연구하고 변경할 수 있습니다</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="100"/>
        <source>You can distribute changed versions of %1</source>
        <translation>변경된 버전의 %1을 배포할 수 있습니다</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>MIT 라이선스는 이러한 자유를 보장합니다. 누구도 이를 빼앗을 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="130"/>
        <source>Third-party Libraries used by %1</source>
        <translation>%1에서 사용하는 타사 라이브러리</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="153"/>
        <source>&amp;Help</source>
        <translation>도움말(&amp;H)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="154"/>
        <source>&amp;About</source>
        <translation>정보(&amp;A)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="156"/>
        <source>&amp;License</source>
        <translation>라이선스(&amp;L)</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <location filename="../graphicsscene.cpp" line="100"/>
        <source>Drag image here</source>
        <translation>이미지를 여기로 끌기</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <source>File url list is empty</source>
        <translation type="vanished">파일 URL 목록이 비어 있습니다</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="50"/>
        <source>File is not a valid image</source>
        <translation>파일이 올바른 이미지가 아닙니다</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="54"/>
        <location filename="../graphicsview.cpp" line="58"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>이미지 데이터가 잘못되었거나 현재 지원되지 않습니다</translation>
    </message>
    <message>
        <source>Image data is invalid</source>
        <translation type="vanished">이미지 데이터가 잘못되었습니다</translation>
    </message>
    <message>
        <source>Not supported mimedata: %1</source>
        <translation type="vanished">지원되지 않는 mimedata: %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>File url list is empty</source>
        <translation>파일 URL 목록이 비어 있습니다</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>&amp;Copy</source>
        <translation>복사(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Image data is invalid</source>
        <translation>이미지 데이터가 잘못되었습니다</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>Not supported mimedata: %1</source>
        <translation>지원되지 않는 mimedata: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>Image From Clipboard</source>
        <translation>클립보드에서 이미지</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="777"/>
        <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
        <translation>&quot;%1&quot;을 휴지통으로 옮기시겠습니까?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Failed to move file to trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
        <translation>휴지통으로 이동하지 못했습니다. 파일 권한 문제, 파일 시스템 제한 또는 플랫폼 제한으로 인해 발생할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="114"/>
        <source>Copy P&amp;ixmap</source>
        <translation>Pixmap 복사(&amp;I)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="115"/>
        <source>Copy &amp;File Path</source>
        <translation>파일 경로 복사(&amp;F)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="133"/>
        <source>Properties</source>
        <translation>속성</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="118"/>
        <location filename="../aboutdialog.cpp" line="41"/>
        <source>Stay on top</source>
        <translation>맨 위에 유지</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="119"/>
        <location filename="../aboutdialog.cpp" line="44"/>
        <source>Protected mode</source>
        <translation>보호 모드</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="120"/>
        <location filename="../aboutdialog.cpp" line="47"/>
        <source>Keep transformation</source>
        <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
        <translation>변형 유지</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="99"/>
        <source>Zoom in</source>
        <translation>확대</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Zoom out</source>
        <translation>축소</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>Pause/Resume Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="109"/>
        <source>Animation Go to Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="111"/>
        <source>Flip &amp;Horizontally</source>
        <translation>수평으로 뒤집기(&amp;H)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="112"/>
        <source>Fit to view</source>
        <translation>보기에 맞춤</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="113"/>
        <source>Fit to width</source>
        <translation>너비에 맞춤</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="116"/>
        <source>&amp;Paste</source>
        <translation>붙여넣기(&amp;P)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="101"/>
        <source>Toggle Checkerboard</source>
        <translation>바둑판 전환</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="95"/>
        <source>&amp;Open...</source>
        <translation>열기(&amp;O)...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Actual size</source>
        <translation>실제 크기</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="98"/>
        <source>Toggle maximize</source>
        <translation>최대화 전환</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="102"/>
        <source>Rotate right</source>
        <translation>오른쪽으로 회전</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Rotate left</source>
        <translation>왼쪽으로 회전</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>Previous image</source>
        <translation>이전 이미지</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Next image</source>
        <translation>다음 이미지</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="776"/>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Move to Trash</source>
        <translation>휴지통으로 이동</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="121"/>
        <source>Configure...</source>
        <translation>구성...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="122"/>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="125"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>파일 탐색기에 표시</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="131"/>
        <source>Show in directory</source>
        <translation>디렉터리에 표시</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="134"/>
        <source>Quit</source>
        <translation>종료</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>이미지 메타데이터</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>기원</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>이미지</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="48"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>카메라</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="35"/>
        <source>%1 File</source>
        <translation>%1 파일</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>설명</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>고급 사진</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="47"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Dimensions</source>
        <translation>치수</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="54"/>
        <source>Aspect ratio</source>
        <translation>종횡비</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="58"/>
        <source>Frame count</source>
        <translation>프레임 수</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Item type</source>
        <translation>항목 유형</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Folder path</source>
        <translation>폴더 경로</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date created</source>
        <translation>만든 날짜</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="72"/>
        <source>Date modified</source>
        <translation>수정 날짜</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Subject</source>
        <translation>주제</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Rating</source>
        <translation>등급</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Tags</source>
        <translation>태그</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="87"/>
        <source>Comments</source>
        <translation>주석</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Authors</source>
        <translation>저자</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="92"/>
        <source>Date taken</source>
        <translation>촬영 날짜</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Program name</source>
        <translation>프로그램 이름</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="100"/>
        <source>Copyright</source>
        <translation>저작권</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Horizontal resolution</source>
        <translation>수평 해상도</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Vertical resolution</source>
        <translation>수직 해상도</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Resolution unit</source>
        <translation>해상도 단위</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="109"/>
        <source>Colour representation</source>
        <translation>색 표현</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera maker</source>
        <translation>카메라 제조업체</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>Camera model</source>
        <translation>카메라 모델</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>F-stop</source>
        <translation>F-스톱</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>Exposure time</source>
        <translation>노출 시간</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>ISO speed</source>
        <translation>ISO 속도</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Exposure bias</source>
        <translation>노출 편향</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Focal length</source>
        <translation>초점 거리</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Max aperture</source>
        <translation>최대 조리개</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Metering mode</source>
        <translation>미터링 모드</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Subject distance</source>
        <translation>피사체 거리</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>Flash mode</source>
        <translation>플래시 모드</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="134"/>
        <source>35mm focal length</source>
        <translation>35mm 초점 거리</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Lens model</source>
        <translation>렌즈 모델</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Contrast</source>
        <translation>대비</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Brightness</source>
        <translation>밝기</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Exposure program</source>
        <translation>노출 프로그램</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Saturation</source>
        <translation>채도</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>Sharpness</source>
        <translation>선명도</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>White balance</source>
        <translation>화이트 밸런스</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>Digital zoom</source>
        <translation>디지털 줌</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="153"/>
        <source>EXIF version</source>
        <translation>EXIF 버전</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude reference</source>
        <translation>위도 참조</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Latitude</source>
        <translation>위도</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude reference</source>
        <translation>경도 참조</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Longitude</source>
        <translation>경도</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude reference</source>
        <translation>고도 참조</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="166"/>
        <source>Altitude</source>
        <translation>고도</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="176"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="194"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Property</source>
        <translation>속성</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Value</source>
        <translation>값</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="31"/>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="61"/>
        <source>Editing shortcuts for action &quot;%1&quot;:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Failed to set shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="78"/>
        <source>Do nothing</source>
        <translation>아무것도 하지 않음</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="79"/>
        <source>Close the window</source>
        <translation>창 닫기</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Toggle maximize</source>
        <translation>최대화 전환</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="81"/>
        <source>Toggle fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="85"/>
        <source>Zoom in and out</source>
        <translation>확대 및 축소</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="86"/>
        <source>View next or previous item</source>
        <translation>다음 또는 이전 항목 보기</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="90"/>
        <source>Auto size</source>
        <translation>자동 크기</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="91"/>
        <source>Maximized</source>
        <translation>최대화</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="92"/>
        <source>Windowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="96"/>
        <source>Round (Integer scaling)</source>
        <comment>This option means round up for .5 and above</comment>
        <translation>라운드 (정수 스케일링)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="97"/>
        <source>Ceil (Integer scaling)</source>
        <comment>This option means always round up</comment>
        <translation>셰일 (정수 스케일링)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="98"/>
        <source>Floor (Integer scaling)</source>
        <comment>This option means always round down</comment>
        <translation>바닥 (정수 스케일링)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="99"/>
        <source>Follow system (Fractional scaling)</source>
        <comment>This option means don&apos;t round</comment>
        <translation>팔로우 시스템 (부분 스케일링)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="122"/>
        <source>Stay on top when start-up</source>
        <translation>시작 시 맨 위에 유지</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="123"/>
        <source>Use built-in close window animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="124"/>
        <source>Use light-color checkerboard</source>
        <translation>밝은 색상의 바둑판 사용</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="125"/>
        <source>Loop the loaded gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <source>Double-click behavior</source>
        <translation>더블클릭 동작</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="127"/>
        <source>Mouse wheel behavior</source>
        <translation>마우스 휠 동작</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>Default window size</source>
        <translation>기본 창 크기</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="129"/>
        <source>HiDPI scale factor rounding policy</source>
        <translation>HiDPI 배율 반올림 정책</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../shortcutedit.cpp" line="109"/>
        <source>No shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <location filename="../shortcutedit.cpp" line="75"/>
        <source>Shortcut #%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Pineapple Pictures</source>
        <translation>파인애플 픽처스</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>List supported image format suffixes, and quit program.</source>
        <translation>지원되는 이미지 형식 접미사를 나열하고 프로그램을 종료합니다.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>File list.</source>
        <translation>파일 목록.</translation>
    </message>
</context>
</TS>
